# HOA Tools

[![Tests status][tests-badge]][tests-link]
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/HumanOrganAtlas/hoa-tools/main.svg)](https://results.pre-commit.ci/latest/github/HumanOrganAtlas/hoa-tools/main)
[![Documentation Status](https://readthedocs.org/projects/hoa-tools/badge/?version=latest)](https://hoa-tools.readthedocs.io/en/latest/?badge=latest)

[![License][license-badge]](./LICENSE.md)

<!--
[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]
-->

<!-- prettier-ignore-start -->
[tests-badge]:              https://github.com/HumanOrganAtlas/hoa-tools/actions/workflows/tests.yml/badge.svg
[tests-link]:               https://github.com/HumanOrganAtlas/hoa-tools/actions/workflows/tests.yml
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/hoa-tools
[conda-link]:               https://github.com/conda-forge/hoa-tools-feedstock
[pypi-link]:                https://pypi.org/project/hoa-tools/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/hoa-tools
[pypi-version]:             https://img.shields.io/pypi/v/hoa-tools
[license-badge]:            https://img.shields.io/badge/License-BSD_3--Clause-blue.svg
<!-- prettier-ignore-end -->

Tools for working with data from the [Human Organ Atlas](https://human-organ-atlas.esrf.eu/).
Documentation at https://hoa-tools.readthedocs.io.
